(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports) :
    typeof define === 'function' && define.amd ? define(['exports'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global.vuepack = {}));
}(this, (function (exports) { 'use strict';

    var mixin = {
        mounted({ img, rect }) {
            return new Promise(resolve => {
                this.ref.style.cssText = `top: ${rect.y}px; left: ${rect.x}px; width: ${img.offsetWidth}px; height: ${img.offsetHeight}px;`;
                this.ref.onload = () => {
                    this.el.classList.add("photo-viewer-open");
                    const { w, h } = this.getdimensions(img.naturalWidth / img.naturalHeight);
                    this.ref.style.setProperty("--enlarged-photo-w", w);
                    this.ref.style.setProperty("--enlarged-photo-h", h);
                    resolve();
                };
                this.ref.srcset = img.dataset.fullsrcset || img.dataset.srcset;
            });
        },
        close(img, el) {
            return new Promise(resolve => {
                setTimeout(() => {
                    el.classList.remove("photo-viewer-close", "photo-viewer-open");
                    img.removeAttribute("style");
                    resolve();
                }, 400);
                el.classList.add("photo-viewer-close");
            });
        },
        getdimensions(aspectR) {
            if (window.innerWidth / window.innerHeight > aspectR)
                return { w: 95 * aspectR + "vh", h: "95vh" };
            else
                return { w: "95vw", h: 95 * (1 / aspectR) + "vw" };
        },
        // utility for photoMultiViewers
        filterimgs(state, img) {
            return state.photolist[img.dataset.group || "rest"].filter((x) => {
                const { w, h } = this.getdimensions(x.ratio);
                x.width = w;
                x.height = h;
                return x.srcset !== img.dataset.srcset;
            });
        },
    };

    function Store() {
        /** handler for different needs */
        const handlers = {
            photo(img) {
                img.addEventListener("load", () => img.classList.add("loaded"));
                img.srcset = img.dataset.srcset;
            },
        };
        /** IntersectionObserver's logic */
        /** handler for the IntersectionObserver */
        async function callback(entries, observer) {
            entries.forEach(entry => {
                if (entry.intersectionRatio <= 0)
                    return;
                const target = entry.target;
                handlers[target.dataset.observerhandler](target);
                observer.unobserve(target);
            });
        }
        /** set up a new IntersectionObserver if in the browser */
        const observer = new IntersectionObserver(callback, { rootMargin: "0px", threshold: 0.05 });
        /** list of photos on the page */
        const photolist = {};
        return { callback, observer, photolist, handlers };
    }
    const mutations = {
        addhandler(state, { name, handler }) {
            state.handlers[name] = handler;
        },
        removeHandler(state, name) {
            delete state.handlers[name];
        },
        addphoto(state, payload) {
            const group = payload.group || "rest";
            if (!state.photolist[group])
                state.photolist[group] = [];
            if (!state.photolist[group].map(x => x.src).includes(payload.src))
                state.photolist[group].push(payload);
        },
    };

    function photo (src, baseSizes, sizes) {
        let genSrcset = "", genSizes = "";
        // example: [480, 1920, 2400, integer, integer ...]
        if (Array.isArray(sizes)) {
            for (let i = 0; i < sizes.length; i++) {
                const sizedsrc = src.replace(baseSizes.thumbnail, baseSizes[sizes[i]]);
                genSrcset += `${sizedsrc} ${sizes[i]}w, `;
            }
        }
        else {
            // example: {480: 363, 1920: 433, 2400: 1234, imgversion: sizetopick, ... }
            const keys = Object.keys(sizes);
            for (let i = 0; i < keys.length; i++) {
                const curSize = keys[i]; //current size
                const sizedsrc = src.replace(baseSizes.thumbnail, baseSizes[curSize]);
                genSrcset += `${sizedsrc} ${keys[i]}w, `;
                if (i < keys.length - 1)
                    genSizes += `(max-width: ${sizes[curSize]}px) ${curSize}px, `;
            }
            genSizes += "100vw";
        }
        return { genSrcset, genSizes };
    }

    function map (key, callback, map) {
        if (typeof google != "undefined" && typeof google.maps != "undefined")
            return;
        /** Create the script tag, set the appropriate attributes */
        const script = document.createElement("script");
        script.src = `https://maps.googleapis.com/maps/api/js?v=weekly&key=${key}&callback=initMap`;
        script.async = true;
        /** Attach your callback function to the `window` object */
        window.initMap = () => callback(map);
        /** Append the 'script' element to 'head' */
        document.head.appendChild(script);
    }

    //

    var script$5 = {
      name: "Photo",
      props: {
        src: String,
        alt: String,
        sizes: [Array, Object],
        dontenlargeonclick: String,
        dontaddtolist: String,
        multiview: String,
        group: String,
      },
      data: () => ({ genSrcset: "", genSizes: null }),
      methods: {
        enlarge() {
          if (!this.$refs.img.classList.contains("loaded") || typeof this.dontenlargeonclick !== "undefined") return;
          const enlarger = typeof this.multiview === "undefined" ? "enlargePhoto" : "enlargeManyPhotos";
          this.$root.$emit(enlarger, { rect: this.$el.getBoundingClientRect(), img: this.$refs.img });
        },
      },
      watch: {
        src() {
          this.genSrcset = photo(this.src, this.$store.state.vuepacksizes, this.sizes).genSrcset;
          if (this.$refs.img.classList.contains("loaded")) this.$refs.img.srcset = this.genSrcset;
        },
      },
      created() {
        const settings = photo(this.src, this.$store.state.vuepacksizes, this.sizes);
        this.genSrcset = settings.genSrcset;
        this.genSizes = settings.genSizes;
      },
      mounted() {
        const img = this.$refs.img;

        if (typeof this.dontaddtolist === "undefined")
          img.addEventListener(
            "load",
            () =>
              this.$store.commit("vuepack/addphoto", {
                src: this.src,
                srcset: this.genSrcset,
                ratio: img.naturalWidth / img.naturalHeight,
                group: this.group,
              }),
            { once: true }
          );
        this.$store.state.vuepack.observer.observe(img);
      },
    };

    function normalizeComponent(template, style, script, scopeId, isFunctionalTemplate, moduleIdentifier
    /* server only */
    , shadowMode, createInjector, createInjectorSSR, createInjectorShadow) {
      if (typeof shadowMode !== 'boolean') {
        createInjectorSSR = createInjector;
        createInjector = shadowMode;
        shadowMode = false;
      } // Vue.extend constructor export interop.


      var options = typeof script === 'function' ? script.options : script; // render functions

      if (template && template.render) {
        options.render = template.render;
        options.staticRenderFns = template.staticRenderFns;
        options._compiled = true; // functional template

        if (isFunctionalTemplate) {
          options.functional = true;
        }
      } // scopedId


      if (scopeId) {
        options._scopeId = scopeId;
      }

      var hook;

      if (moduleIdentifier) {
        // server build
        hook = function hook(context) {
          // 2.3 injection
          context = context || // cached call
          this.$vnode && this.$vnode.ssrContext || // stateful
          this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext; // functional
          // 2.2 with runInNewContext: true

          if (!context && typeof __VUE_SSR_CONTEXT__ !== 'undefined') {
            context = __VUE_SSR_CONTEXT__;
          } // inject component styles


          if (style) {
            style.call(this, createInjectorSSR(context));
          } // register component module identifier for async chunk inference


          if (context && context._registeredComponents) {
            context._registeredComponents.add(moduleIdentifier);
          }
        }; // used by ssr in case component is cached and beforeCreate
        // never gets called


        options._ssrRegister = hook;
      } else if (style) {
        hook = shadowMode ? function () {
          style.call(this, createInjectorShadow(this.$root.$options.shadowRoot));
        } : function (context) {
          style.call(this, createInjector(context));
        };
      }

      if (hook) {
        if (options.functional) {
          // register for functional component in vue file
          var originalRender = options.render;

          options.render = function renderWithStyleInjection(h, context) {
            hook.call(context);
            return originalRender(h, context);
          };
        } else {
          // inject component registration as beforeCreate hook
          var existing = options.beforeCreate;
          options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
        }
      }

      return script;
    }

    var normalizeComponent_1 = normalizeComponent;

    /* script */
    const __vue_script__$5 = script$5;

    /* template */
    var __vue_render__$5 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{staticClass:"medium-pack-photo",on:{"click":_vm.enlarge}},[_c('img',{ref:"img",attrs:{"src":_vm.src,"data-srcset":_vm.genSrcset,"sizes":_vm.genSizes,"alt":_vm.alt,"data-group":_vm.group,"data-observerhandler":"photo"}}),_c('span',{staticClass:"cross"})])};
    var __vue_staticRenderFns__$5 = [];

      /* style */
      const __vue_inject_styles__$5 = undefined;
      /* scoped */
      const __vue_scope_id__$5 = undefined;
      /* module identifier */
      const __vue_module_identifier__$5 = undefined;
      /* functional template */
      const __vue_is_functional_template__$5 = false;
      /* style inject */
      
      /* style inject SSR */
      
      /* style inject shadow dom */
      

      
      const __vue_component__$5 = /*#__PURE__*/normalizeComponent_1(
        { render: __vue_render__$5, staticRenderFns: __vue_staticRenderFns__$5 },
        __vue_inject_styles__$5,
        __vue_script__$5,
        __vue_scope_id__$5,
        __vue_is_functional_template__$5,
        __vue_module_identifier__$5,
        false,
        undefined,
        undefined,
        undefined
      );

    //

    var script$4 = {
      props: {
        apikey: String,
        callback: Function,
      },
      mounted() {
        this.$store.commit("vuepack/addhandler", {
          name: "map",
          handler: () => map(this.apikey, this.callback, this.$el),
        });
        this.$store.state.vuepack.observer.observe(this.$el);
      },
    };

    /* script */
    const __vue_script__$4 = script$4;

    /* template */
    var __vue_render__$4 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('section',{attrs:{"data-observerhandler":"map"}})};
    var __vue_staticRenderFns__$4 = [];

      /* style */
      const __vue_inject_styles__$4 = undefined;
      /* scoped */
      const __vue_scope_id__$4 = undefined;
      /* module identifier */
      const __vue_module_identifier__$4 = undefined;
      /* functional template */
      const __vue_is_functional_template__$4 = false;
      /* style inject */
      
      /* style inject SSR */
      
      /* style inject shadow dom */
      

      
      const __vue_component__$4 = /*#__PURE__*/normalizeComponent_1(
        { render: __vue_render__$4, staticRenderFns: __vue_staticRenderFns__$4 },
        __vue_inject_styles__$4,
        __vue_script__$4,
        __vue_scope_id__$4,
        __vue_is_functional_template__$4,
        __vue_module_identifier__$4,
        false,
        undefined,
        undefined,
        undefined
      );

    var Mixin = {
      mounted() {
        const handler = mixin.mounted.bind({ ref: this.$refs.img, el: this.$el, getdimensions: mixin.getdimensions });
        this.enlargeHandler = handler;
      },
      methods: {
        close() {
          return mixin.close(this.$refs.img, this.$el);
        },
        getdimensions: mixin.getdimensions,
      },
    };

    //

    var script$3 = {
      mixins: [Mixin],
      name: "PhotoViewer",
      data: () => ({ trigger: "enlargePhoto" }),
      mounted() {
        this.$root.$on(this.trigger, (data) => this.enlargeHandler(data));
      },
    };

    /* script */
    const __vue_script__$3 = script$3;

    /* template */
    var __vue_render__$3 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('section',{staticClass:"photo-viewer",on:{"click":_vm.close}},[_c('img',{ref:"img",staticClass:"viewed-photo"})])};
    var __vue_staticRenderFns__$3 = [];

      /* style */
      const __vue_inject_styles__$3 = undefined;
      /* scoped */
      const __vue_scope_id__$3 = undefined;
      /* module identifier */
      const __vue_module_identifier__$3 = undefined;
      /* functional template */
      const __vue_is_functional_template__$3 = false;
      /* style inject */
      
      /* style inject SSR */
      
      /* style inject shadow dom */
      

      
      const __vue_component__$3 = /*#__PURE__*/normalizeComponent_1(
        { render: __vue_render__$3, staticRenderFns: __vue_staticRenderFns__$3 },
        __vue_inject_styles__$3,
        __vue_script__$3,
        __vue_scope_id__$3,
        __vue_is_functional_template__$3,
        __vue_module_identifier__$3,
        false,
        undefined,
        undefined,
        undefined
      );

    class default_1 {
        init() {
            this.slideNext(this.settings.initialSlide, 0);
        }
        base(dist, dur) {
            return new Promise((resolve) => {
                this.counter -= dist;
                if (this.counter > 0)
                    this.counter = 0;
                if (this.counter < -1 * (this.slides.length - this.slideDisplay))
                    this.counter = -1 * (this.slides.length - this.slideDisplay);
                this.container.style.transition = "transform " + dur + "ms";
                this.transform(this.counter);
                setTimeout(() => {
                    this.container.style.transition = "initial";
                    resolve();
                }, dur);
            });
        }
        slideNext(dist = Math.ceil((this.pos.start - this.getTransX()) / this.slideWidth), dur = this.settings.transitionSpeed) {
            return this.base(dist, dur);
        }
        slidePrev(dist = Math.floor((this.pos.start - this.getTransX()) / this.slideWidth), dur = this.settings.transitionSpeed) {
            return this.base(dist, dur);
        }
        slideTo(to = 0) {
            return this.slideBy(to - Math.abs(this.counter));
        }
        slideBy(dist = 0) {
            if (dist === 0)
                return new Promise((resolve) => resolve());
            if (dist > 0)
                return this.slideNext(dist);
            else
                return this.slidePrev(dist);
        }
    }
    default_1.carousel = false;

    class Slidehander {
        init() {
            this.container.addEventListener("pointerdown", (pEvent) => pointerDown.call(this, pEvent), {
                once: true,
            });
            /** remove the pointer down event listener when destroying */
            this.container.addEventListener("destroy", () => {
                this.container.removeEventListener("pointerdown", (pEvent) => pointerDown.call(this, pEvent));
            });
        }
    }
    function pointerDown(pEvent) {
        this.pos.start = this.getTransX();
        this.pos.x2 = pEvent.clientX;
        switch (pEvent.pointerType) {
            case "mouse":
                document.onmousemove = (mEvent) => mouseMove.call(this, mEvent);
                document.onmouseup = () => dragstop.call(this);
                break;
            case "touch":
                document.ontouchmove = (tEvent) => touchMove.call(this, tEvent);
                document.ontouchend = () => dragstop.call(this);
                break;
        }
    }
    function mouseMove(mEvent) {
        this.pos.x1 = this.pos.x2 - mEvent.clientX;
        this.pos.x2 = mEvent.clientX;
        this.transformAbsolute(this.getTransX() - this.pos.x1);
        this.container.dispatchEvent(new CustomEvent("moving"));
    }
    function touchMove(tEvent) {
        this.pos.x1 = this.pos.x2 - tEvent.touches[0].clientX;
        this.pos.x2 = tEvent.touches[0].clientX;
        this.pos.y1 = this.pos.y2 - tEvent.touches[0].clientY;
        this.pos.y2 = tEvent.touches[0].clientY;
        /** run only if the finger is moving roughly horizontally */
        if (Math.abs(this.pos.y1) < Math.abs(this.pos.x1))
            this.transformAbsolute(this.getTransX() - this.pos.x1);
        this.container.dispatchEvent(new CustomEvent("moving"));
    }
    async function dragstop() {
        document.onmousemove = null;
        document.ontouchmove = null;
        document.ontouchend = null;
        document.onmouseup = null;
        this.container.dispatchEvent(new CustomEvent("dragstop", {}));
        this.container.onpointerdown = null;
        if (this.pos.start != this.getTransX()) {
            if (this.pos.start > this.getTransX())
                await this.slideNext();
            else
                await this.slidePrev();
        }
        this.container.onpointerdown = (pEvent) => pointerDown.call(this, pEvent);
        this.container.dispatchEvent(new CustomEvent("transitionend", {}));
    }

    var buttons = (options) => function buttons() {
        const nextBtn = document.querySelector(options.nextBtn);
        const prevBtn = document.querySelector(options.prevBtn);
        nextBtn.onclick = btnAct.bind(this, { btn: nextBtn, dist: 1 });
        prevBtn.onclick = btnAct.bind(this, { btn: prevBtn, dist: -1 });
        /** clear event listeners when destroying */
        this.container.addEventListener("destroy", () => {
            nextBtn.onclick = null;
            prevBtn.onclick = null;
        }, { once: true });
        return { prevBtn, nextBtn };
    };
    async function btnAct(params) {
        params.btn.onclick = null;
        this.container.dispatchEvent(new PointerEvent("pointerdown", { pointerType: "mouse" }));
        document.dispatchEvent(new TouchEvent("touchend", {}));
        document.dispatchEvent(new MouseEvent("mouseup", {}));
        await this.slideBy(params.dist);
        this.container.dispatchEvent(new CustomEvent("transitionend", {}));
        params.btn.onclick = btnAct.bind(this, params);
    }

    var lazyloading = (addClass = "loaded", options = { rootMargin: "0px", threshold: 0.5 }) => function lazyloading() {
        const observer = new IntersectionObserver(entries => {
            entries.forEach(entry => {
                if (entry.intersectionRatio <= 0)
                    return;
                const img = entry.target;
                if (!img.dataset.srcset)
                    img.src = img.dataset.src;
                else
                    img.srcset = img.dataset.srcset;
                observer.unobserve(img);
                img.addEventListener("load", () => img.classList.add(addClass));
            });
        }, options);
        this.container.querySelectorAll(".ms-lazy").forEach(img => observer.observe(img));
    };

    const defaults = {
        transitionSpeed: 300,
        initialSlide: 0,
        container: "",
        plugins: []
    };
    function extend(options) {
        const extended = Object.assign({}, defaults);
        for (const counter in defaults) {
            if (options[counter]) {
                extended[counter] = options[counter];
            }
        }
        return extended;
    }

    /** import default settings + types */
    /** copies methods and properties from mixin classes to the derived class
     * it is a modified version of the function here: {@link https://www.typescriptlang.org/docs/handbook/mixins.html#alternative-pattern}
     */
    function setup(...constructors) {
        const base = getBase();
        base.prototype.inits = [];
        base.prototype.destroys = [];
        constructors.forEach(baseCtor => {
            /** copy the init functions to the inits array */
            if (Object.hasOwnProperty.call(baseCtor.prototype, "init")) {
                base.prototype.inits.push(baseCtor.prototype.init);
            }
            /** copy methods */
            Object.getOwnPropertyNames(baseCtor.prototype).forEach(name => {
                Object.defineProperty(base.prototype, name, Object.getOwnPropertyDescriptor(baseCtor.prototype, name) || Object.create(null));
            });
        });
        return base;
    }
    function getBase() {
        return class {
            constructor(settings) {
                this.pos = { start: 0, x1: 0, x2: 0, y1: 0, y2: 0 };
                this.plugins = {};
                this.counter = 0;
                this.settings = extend(settings);
                this.container = document.getElementById(settings.container);
                this.slides = this.container.children;
                this.container.style.setProperty("--number-of-slides", this.slides.length);
                this.slideWidth = this.calcSlideWidth();
                this.slideDisplay = this.getSlidesPerView();
                window.addEventListener("resize", () => {
                    this.slideWidth = this.calcSlideWidth();
                    this.slideDisplay = this.getSlidesPerView();
                });
                /** initiate mixins */
                for (const init of this.inits)
                    init.call(this);
                /** initiate plugins */
                for (const plugin of this.settings.plugins)
                    this.plugins[plugin.name] = plugin.call(this);
            }
            /** updating utilities */
            getTransX() {
                return parseFloat(window.getComputedStyle(this.container).transform.split(", ")[4]);
            }
            getProperty(el, elProp) {
                return parseInt(window.getComputedStyle(el).getPropertyValue(elProp));
            }
            calcSlideWidth() {
                return (this.slides[0].offsetWidth +
                    this.getProperty(this.slides[0], "margin-left") +
                    this.getProperty(this.slides[0], "margin-right"));
            }
            getSlidesPerView() {
                const slidesPerView = this.getProperty(this.container.parentElement, "--slides-per-view");
                return !isNaN(slidesPerView) ? slidesPerView : this.getProperty(document.documentElement, "--slides-per-view");
            }
            /**
             * a utility for transforming the container by the length of one slide mulitplied by @param dist
             * mainly used for transforming to another slide
             */
            transform(dist) {
                this.container.style.transform = "translate3d(" + this.slideWidth * dist + "px,0,0)";
            }
            /**
             * a utility for transforming the container by an absolute number of px specified by @param Absolutedist
             * mainly used for handling touch/mouse events
             */
            transformAbsolute(Absolutedist) {
                this.container.style.transform = "translate3d(" + Absolutedist + "px,0,0)";
            }
            destroy() {
                this.container.dispatchEvent(new CustomEvent("destroy"));
                this.transform(0);
            }
        };
    }

    //

    const Slider = setup(Slidehander, default_1);
    var script$2 = {
      mixins: [Mixin],
      name: "PhotoMultiViewer",
      data: () => ({
        svgPath:
          "M.52 24a.5.52 0 01-.35-.9L10.8 12 .17.93a.5.52 0 11.7-.74l10.99 11.46c.19.2.19.54 0 .73L.88 23.84a.5.5 0 01-.36.16z",
        trigger: "enlargeManyPhotos",
        imgs: [],
        slider: null,
      }),
      async mounted() {
        this.$root.$on(this.trigger, async ({ img, rect }) => {
          this.imgs = mixin.filterimgs(this.$store.state.vuepack, img);
          await this.enlargeHandler({ img, rect });
          this.slider = new Slider({
            container: "photo-slider",
            transitionSpeed: 500,
            plugins: [lazyloading(), buttons({ prevBtn: "#multi-viewer-prev", nextBtn: "#multi-viewer-next" })],
          });
        });
      },
      methods: {
        async closeviewer() {
          await this.close();
          this.imgs = [];
          this.slider.slideTo(0);
          this.slider.destroy();
          this.$refs.img.removeAttribute("style");
        },
      },
    };

    /* script */
    const __vue_script__$2 = script$2;

    /* template */
    var __vue_render__$2 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('section',{staticClass:"photo-multi-viewer photo-viewer ms-outer-con width-in-percentage"},[_c('div',{staticClass:"photo-slider ms-inner-con",attrs:{"id":"photo-slider"}},[_c('div',{staticClass:"first-slide"},[_c('img',{ref:"img",staticClass:"viewed-photo"})]),_vm._l((_vm.imgs),function(img){return _c('div',{key:img.src,staticClass:"other-slides"},[_c('div',{staticClass:"wrapper"},[_c('div',{staticClass:"medium-pack-photo no-hover",style:({ '--enlarged-photo-w': img.width, '--enlarged-photo-h': img.height })},[_c('img',{staticClass:"ms-lazy",attrs:{"src":img.src,"data-srcset":img.srcset}})])])])})],2),_c('button',{attrs:{"id":"multi-viewer-prev"}},[_c('svg',{attrs:{"xmlns":"http://www.w3.org/2000/svg","width":"12","height":"24","viewBox":"0 0 12 24"}},[_c('path',{attrs:{"d":_vm.svgPath}})])]),_c('button',{attrs:{"id":"multi-viewer-next"}},[_c('svg',{attrs:{"xmlns":"http://www.w3.org/2000/svg","width":"12","height":"24","viewBox":"0 0 12 24"}},[_c('path',{attrs:{"d":_vm.svgPath}})])]),_c('button',{attrs:{"id":"close-multi-viewer"},on:{"click":_vm.closeviewer}})])};
    var __vue_staticRenderFns__$2 = [];

      /* style */
      const __vue_inject_styles__$2 = undefined;
      /* scoped */
      const __vue_scope_id__$2 = undefined;
      /* module identifier */
      const __vue_module_identifier__$2 = undefined;
      /* functional template */
      const __vue_is_functional_template__$2 = false;
      /* style inject */
      
      /* style inject SSR */
      
      /* style inject shadow dom */
      

      
      const __vue_component__$2 = /*#__PURE__*/normalizeComponent_1(
        { render: __vue_render__$2, staticRenderFns: __vue_staticRenderFns__$2 },
        __vue_inject_styles__$2,
        __vue_script__$2,
        __vue_scope_id__$2,
        __vue_is_functional_template__$2,
        __vue_module_identifier__$2,
        false,
        undefined,
        undefined,
        undefined
      );

    const vuepack = {
      namespaced: true,
      state: Store,
      mutations,
    };

    //
    //
    //
    //
    //
    //
    //
    //
    //
    //
    //
    //
    //
    //

    var script$1 = {
      data: () => ({ isActive: false }),
    };

    /* script */
    const __vue_script__$1 = script$1;

    /* template */
    var __vue_render__$1 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('nav',{staticClass:"navbar"},[_vm._t("logo"),_c('div',{staticClass:"nav",style:(_vm.isActive ? 'transform: translateX(-100%)' : '')},[_vm._t("default")],2),_c('div',{staticClass:"hamburger-container",on:{"click":function($event){_vm.isActive = !_vm.isActive;}}},[_c('div',{staticClass:"hamburger",class:{ 'is-active': _vm.isActive }},[_c('div',{staticClass:"hamburger-inner"})])])],2)};
    var __vue_staticRenderFns__$1 = [];

      /* style */
      const __vue_inject_styles__$1 = undefined;
      /* scoped */
      const __vue_scope_id__$1 = undefined;
      /* module identifier */
      const __vue_module_identifier__$1 = undefined;
      /* functional template */
      const __vue_is_functional_template__$1 = false;
      /* style inject */
      
      /* style inject SSR */
      
      /* style inject shadow dom */
      

      
      const __vue_component__$1 = /*#__PURE__*/normalizeComponent_1(
        { render: __vue_render__$1, staticRenderFns: __vue_staticRenderFns__$1 },
        __vue_inject_styles__$1,
        __vue_script__$1,
        __vue_scope_id__$1,
        __vue_is_functional_template__$1,
        __vue_module_identifier__$1,
        false,
        undefined,
        undefined,
        undefined
      );

    //
    var script = {
      name: "Footer",
      components: { Photo: __vue_component__$5 },
      props: {
        name: String,
        background: String,
        references: Array,
      },
    };

    /* script */
    const __vue_script__ = script;

    /* template */
    var __vue_render__ = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('footer',{staticClass:"footer"},[_c('div',{staticClass:"footer-bg"},[_c('Photo',{staticClass:"w-full h-96 no-hover",attrs:{"dontenlargeonclick":"","src":_vm.background,"sizes":[720, 1290, 1920, 2400]}}),_c('div',{staticClass:"footer-text"},[_vm._t("default")],2)],1),_c('div',{staticClass:"footer-links"},_vm._l((_vm.references),function(reference){return _c('div',{key:reference.id,staticClass:"footer-links-col"},[_c('h3',[_vm._v(_vm._s(reference.name))]),_vm._l((reference.links),function(link){return _c('ul',{key:link.id},[_c('li',[_c('a',{attrs:{"href":link.url}},[_vm._v(_vm._s(link.name))])])])})],2)}),0),_c('div',{staticClass:"footer-copyright"},[_vm._v("Copyright © "+_vm._s(_vm.name)+" "+_vm._s(new Date().getFullYear()))])])};
    var __vue_staticRenderFns__ = [];

      /* style */
      const __vue_inject_styles__ = undefined;
      /* scoped */
      const __vue_scope_id__ = undefined;
      /* module identifier */
      const __vue_module_identifier__ = undefined;
      /* functional template */
      const __vue_is_functional_template__ = false;
      /* style inject */
      
      /* style inject SSR */
      
      /* style inject shadow dom */
      

      
      const __vue_component__ = /*#__PURE__*/normalizeComponent_1(
        { render: __vue_render__, staticRenderFns: __vue_staticRenderFns__ },
        __vue_inject_styles__,
        __vue_script__,
        __vue_scope_id__,
        __vue_is_functional_template__,
        __vue_module_identifier__,
        false,
        undefined,
        undefined,
        undefined
      );

    // What should happen if the user installs the library as a plugin
    function install(Vue) {
      Vue.component("Photo", __vue_component__$5);
      Vue.component("PhotoViewer", __vue_component__$3);
      Vue.component("PhotoMultiViewer", __vue_component__$2);
    }

    exports.Footer = __vue_component__;
    exports.Map = __vue_component__$4;
    exports.Navbar = __vue_component__$1;
    exports.Photo = __vue_component__$5;
    exports.PhotoMultiViewer = __vue_component__$2;
    exports.PhotoViewer = __vue_component__$3;
    exports['default'] = install;
    exports.vuepack = vuepack;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
